"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class SlackChannelEndpointDtoTypedDict(TypedDict):
    channel_id: str
    r"""Slack channel ID"""


class SlackChannelEndpointDto(BaseModel):
    channel_id: Annotated[str, pydantic.Field(alias="channelId")]
    r"""Slack channel ID"""
