"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .layoutresponsedto import LayoutResponseDto, LayoutResponseDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ListLayoutResponseDtoTypedDict(TypedDict):
    layouts: List[LayoutResponseDtoTypedDict]
    r"""List of layouts"""
    total_count: float
    r"""Total number of layouts"""


class ListLayoutResponseDto(BaseModel):
    layouts: List[LayoutResponseDto]
    r"""List of layouts"""

    total_count: Annotated[float, pydantic.Field(alias="totalCount")]
    r"""Total number of layouts"""
