"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emailcontrolsdto import EmailControlsDto, EmailControlsDtoTypedDict
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ControlValuesTypedDict(TypedDict):
    r"""Control values for the layout"""

    email: NotRequired[EmailControlsDtoTypedDict]
    r"""Email layout controls"""


class ControlValues(BaseModel):
    r"""Control values for the layout"""

    email: Optional[EmailControlsDto] = None
    r"""Email layout controls"""


class UpdateLayoutDtoTypedDict(TypedDict):
    name: str
    r"""Name of the layout"""
    is_translation_enabled: NotRequired[bool]
    r"""Enable or disable translations for this layout"""
    control_values: NotRequired[Nullable[ControlValuesTypedDict]]
    r"""Control values for the layout"""


class UpdateLayoutDto(BaseModel):
    name: str
    r"""Name of the layout"""

    is_translation_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="isTranslationEnabled")
    ] = False
    r"""Enable or disable translations for this layout"""

    control_values: Annotated[
        OptionalNullable[ControlValues], pydantic.Field(alias="controlValues")
    ] = UNSET
    r"""Control values for the layout"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["isTranslationEnabled", "controlValues"]
        nullable_fields = ["controlValues"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
