"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DataTypedDict(TypedDict):
    pass


class Data(BaseModel):
    pass


class TenantPayloadDtoTypedDict(TypedDict):
    identifier: NotRequired[str]
    name: NotRequired[str]
    data: NotRequired[DataTypedDict]


class TenantPayloadDto(BaseModel):
    identifier: Optional[str] = None

    name: Optional[str] = None

    data: Optional[Data] = None
