"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LayoutCreationSourceEnum(str, Enum):
    r"""Source of layout creation"""

    DASHBOARD = "dashboard"
