"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .layoutpreviewpayloaddto import (
    LayoutPreviewPayloadDto,
    LayoutPreviewPayloadDtoTypedDict,
)
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class LayoutPreviewRequestDtoTypedDict(TypedDict):
    control_values: NotRequired[Dict[str, Any]]
    r"""Optional control values for layout preview"""
    preview_payload: NotRequired[LayoutPreviewPayloadDtoTypedDict]
    r"""Optional payload for layout preview"""


class LayoutPreviewRequestDto(BaseModel):
    control_values: Annotated[
        Optional[Dict[str, Any]], pydantic.Field(alias="controlValues")
    ] = None
    r"""Optional control values for layout preview"""

    preview_payload: Annotated[
        Optional[LayoutPreviewPayloadDto], pydantic.Field(alias="previewPayload")
    ] = None
    r"""Optional payload for layout preview"""
