"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TranslationControllerDeleteTranslationEndpointPathParamResourceType(str, Enum):
    r"""Resource type"""

    WORKFLOW = "workflow"
    LAYOUT = "layout"


class TranslationControllerDeleteTranslationEndpointRequestTypedDict(TypedDict):
    resource_type: TranslationControllerDeleteTranslationEndpointPathParamResourceType
    r"""Resource type"""
    resource_id: str
    r"""Resource ID"""
    locale: str
    r"""Locale code"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TranslationControllerDeleteTranslationEndpointRequest(BaseModel):
    resource_type: Annotated[
        TranslationControllerDeleteTranslationEndpointPathParamResourceType,
        pydantic.Field(alias="resourceType"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Resource type"""

    resource_id: Annotated[
        str,
        pydantic.Field(alias="resourceId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Resource ID"""

    locale: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Locale code"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""
