"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MessageStatusEnum(str, Enum):
    r"""Status of the message"""

    SENT = "sent"
    ERROR = "error"
    WARNING = "warning"
