"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emailcontrolsdto import EmailControlsDto, EmailControlsDtoTypedDict
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LayoutControlValuesDtoTypedDict(TypedDict):
    email: NotRequired[EmailControlsDtoTypedDict]
    r"""Email layout controls"""


class LayoutControlValuesDto(BaseModel):
    email: Optional[EmailControlsDto] = None
    r"""Email layout controls"""
