"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ContentIssueEnum(str, Enum):
    r"""Type of step content issue"""

    ILLEGAL_VARIABLE_IN_CONTROL_VALUE = "ILLEGAL_VARIABLE_IN_CONTROL_VALUE"
    INVALID_FILTER_ARG_IN_VARIABLE = "INVALID_FILTER_ARG_IN_VARIABLE"
    MISSING_VALUE = "MISSING_VALUE"
    TIER_LIMIT_EXCEEDED = "TIER_LIMIT_EXCEEDED"
