"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class DelayScheduledMetadataType(str, Enum):
    SCHEDULED = "scheduled"


class DelayScheduledMetadataTypedDict(TypedDict):
    type: DelayScheduledMetadataType
    delay_path: str


class DelayScheduledMetadata(BaseModel):
    type: DelayScheduledMetadataType

    delay_path: Annotated[str, pydantic.Field(alias="delayPath")]
