"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class UpdateSubscriberOnlineFlagRequestDtoTypedDict(TypedDict):
    is_online: bool


class UpdateSubscriberOnlineFlagRequestDto(BaseModel):
    is_online: Annotated[bool, pydantic.Field(alias="isOnline")]
