"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ChannelCTATypeEnum(str, Enum):
    r"""Type of call to action"""

    REDIRECT = "redirect"
