"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .layoutcreationsourceenum import LayoutCreationSourceEnum
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateLayoutDtoTypedDict(TypedDict):
    layout_id: str
    r"""Unique identifier for the layout"""
    name: str
    r"""Name of the layout"""
    is_translation_enabled: NotRequired[bool]
    r"""Enable or disable translations for this layout"""
    source: NotRequired[LayoutCreationSourceEnum]
    r"""Source of layout creation"""


class CreateLayoutDto(BaseModel):
    layout_id: Annotated[str, pydantic.Field(alias="layoutId")]
    r"""Unique identifier for the layout"""

    name: str
    r"""Name of the layout"""

    is_translation_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="isTranslationEnabled")
    ] = False
    r"""Enable or disable translations for this layout"""

    source: Annotated[
        Optional[LayoutCreationSourceEnum], pydantic.Field(alias="__source")
    ] = LayoutCreationSourceEnum.DASHBOARD
    r"""Source of layout creation"""
