"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channelcredentials import ChannelCredentials, ChannelCredentialsTypedDict
from .chatorpushproviderenum import ChatOrPushProviderEnum
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateSubscriberChannelRequestDtoTypedDict(TypedDict):
    provider_id: ChatOrPushProviderEnum
    r"""The provider identifier for the credentials"""
    credentials: ChannelCredentialsTypedDict
    r"""Credentials payload for the specified provider"""
    integration_identifier: NotRequired[str]
    r"""The integration identifier"""


class UpdateSubscriberChannelRequestDto(BaseModel):
    provider_id: Annotated[ChatOrPushProviderEnum, pydantic.Field(alias="providerId")]
    r"""The provider identifier for the credentials"""

    credentials: ChannelCredentials
    r"""Credentials payload for the specified provider"""

    integration_identifier: Annotated[
        Optional[str], pydantic.Field(alias="integrationIdentifier")
    ] = None
    r"""The integration identifier"""
