"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberresponsedtooptional import (
    SubscriberResponseDtoOptional,
    SubscriberResponseDtoOptionalTypedDict,
)
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LayoutPreviewPayloadDtoTypedDict(TypedDict):
    subscriber: NotRequired[SubscriberResponseDtoOptionalTypedDict]
    r"""Partial subscriber information"""


class LayoutPreviewPayloadDto(BaseModel):
    subscriber: Optional[SubscriberResponseDtoOptional] = None
    r"""Partial subscriber information"""
