"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class PhoneEndpointDtoTypedDict(TypedDict):
    phone_number: str
    r"""Phone number in E.164 format"""


class PhoneEndpointDto(BaseModel):
    phone_number: Annotated[str, pydantic.Field(alias="phoneNumber")]
    r"""Phone number in E.164 format"""
