"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class GetMasterJSONResponseDtoTypedDict(TypedDict):
    workflows: Dict[str, Any]
    r"""All translations for given locale organized by workflow identifier"""
    layouts: Dict[str, Any]
    r"""All translations for given locale organized by layout identifier"""


class GetMasterJSONResponseDto(BaseModel):
    workflows: Dict[str, Any]
    r"""All translations for given locale organized by workflow identifier"""

    layouts: Dict[str, Any]
    r"""All translations for given locale organized by layout identifier"""
