"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class UploadTranslationsResponseDtoTypedDict(TypedDict):
    total_files: float
    r"""Total number of files processed"""
    successful_uploads: float
    r"""Number of files successfully uploaded"""
    failed_uploads: float
    r"""Number of files that failed to upload"""
    errors: List[str]
    r"""List of error messages for failed uploads"""


class UploadTranslationsResponseDto(BaseModel):
    total_files: Annotated[float, pydantic.Field(alias="totalFiles")]
    r"""Total number of files processed"""

    successful_uploads: Annotated[float, pydantic.Field(alias="successfulUploads")]
    r"""Number of files successfully uploaded"""

    failed_uploads: Annotated[float, pydantic.Field(alias="failedUploads")]
    r"""Number of files that failed to upload"""

    errors: List[str]
    r"""List of error messages for failed uploads"""
