"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class UpdateContextRequestDtoTypedDict(TypedDict):
    data: Dict[str, Any]
    r"""Custom data to associate with this context. Replaces existing data."""


class UpdateContextRequestDto(BaseModel):
    data: Dict[str, Any]
    r"""Custom data to associate with this context. Replaces existing data."""
