"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .workflowinfodto import WorkflowInfoDto, WorkflowInfoDtoTypedDict
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class GetLayoutUsageResponseDtoTypedDict(TypedDict):
    workflows: List[WorkflowInfoDtoTypedDict]
    r"""Array of workflows that use this layout"""


class GetLayoutUsageResponseDto(BaseModel):
    workflows: List[WorkflowInfoDto]
    r"""Array of workflows that use this layout"""
