"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UISchemaGroupEnum(str, Enum):
    r"""Group of the UI Schema"""

    IN_APP = "IN_APP"
    EMAIL = "EMAIL"
    DIGEST = "DIGEST"
    DELAY = "DELAY"
    THROTTLE = "THROTTLE"
    SMS = "SMS"
    CHAT = "CHAT"
    PUSH = "PUSH"
    SKIP = "SKIP"
    LAYOUT = "LAYOUT"
