"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChannelCredentialsDtoTypedDict(TypedDict):
    webhook_url: NotRequired[str]
    r"""The URL for the webhook associated with the channel."""
    device_tokens: NotRequired[List[str]]
    r"""An array of device tokens for push notifications."""


class ChannelCredentialsDto(BaseModel):
    webhook_url: Annotated[Optional[str], pydantic.Field(alias="webhookUrl")] = None
    r"""The URL for the webhook associated with the channel."""

    device_tokens: Annotated[
        Optional[List[str]], pydantic.Field(alias="deviceTokens")
    ] = None
    r"""An array of device tokens for push notifications."""
