"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .delaycontroldto import DelayControlDto, DelayControlDtoTypedDict
from .uischema import UISchema, UISchemaTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DelayControlsMetadataResponseDtoTypedDict(TypedDict):
    values: DelayControlDtoTypedDict
    r"""Control values specific to Delay"""
    data_schema: NotRequired[Dict[str, Any]]
    r"""JSON Schema for data"""
    ui_schema: NotRequired[UISchemaTypedDict]
    r"""UI Schema for rendering"""


class DelayControlsMetadataResponseDto(BaseModel):
    values: DelayControlDto
    r"""Control values specific to Delay"""

    data_schema: Annotated[
        Optional[Dict[str, Any]], pydantic.Field(alias="dataSchema")
    ] = None
    r"""JSON Schema for data"""

    ui_schema: Annotated[Optional[UISchema], pydantic.Field(alias="uiSchema")] = None
    r"""UI Schema for rendering"""
