"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateTopicRequestDtoTypedDict(TypedDict):
    name: str
    r"""The display name for the topic"""


class UpdateTopicRequestDto(BaseModel):
    name: str
    r"""The display name for the topic"""
