"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class MsTeamsUserEndpointDtoTypedDict(TypedDict):
    user_id: str
    r"""MS Teams user ID"""


class MsTeamsUserEndpointDto(BaseModel):
    user_id: Annotated[str, pydantic.Field(alias="userId")]
    r"""MS Teams user ID"""
