"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .textalignenum import TextAlignEnum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class EmailBlockStylesTypedDict(TypedDict):
    text_align: TextAlignEnum
    r"""Text alignment for the email block"""


class EmailBlockStyles(BaseModel):
    text_align: Annotated[TextAlignEnum, pydantic.Field(alias="textAlign")]
    r"""Text alignment for the email block"""
