"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class RemoveSubscriberResponseDtoTypedDict(TypedDict):
    acknowledged: bool
    r"""Indicates whether the operation was acknowledged by the server"""
    status: str
    r"""Status of the subscriber removal operation"""


class RemoveSubscriberResponseDto(BaseModel):
    acknowledged: bool
    r"""Indicates whether the operation was acknowledged by the server"""

    status: str
    r"""Status of the subscriber removal operation"""
