"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class EmailBlockTypeEnum(str, Enum):
    r"""Type of the email block"""

    BUTTON = "button"
    TEXT = "text"
