"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .contentissueenum import ContentIssueEnum
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class StepContentIssueDtoTypedDict(TypedDict):
    issue_type: ContentIssueEnum
    r"""Type of step content issue"""
    message: str
    r"""Detailed message describing the issue"""
    variable_name: NotRequired[str]
    r"""Name of the variable related to the issue"""


class StepContentIssueDto(BaseModel):
    issue_type: Annotated[ContentIssueEnum, pydantic.Field(alias="issueType")]
    r"""Type of step content issue"""

    message: str
    r"""Detailed message describing the issue"""

    variable_name: Annotated[Optional[str], pydantic.Field(alias="variableName")] = None
    r"""Name of the variable related to the issue"""
