"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, QueryParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TranslationControllerGetMasterJSONEndpointRequestTypedDict(TypedDict):
    locale: NotRequired[str]
    r"""Locale to export. If not provided, exports organization default locale"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TranslationControllerGetMasterJSONEndpointRequest(BaseModel):
    locale: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Locale to export. If not provided, exports organization default locale"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""
