"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class ActivityTopicDtoTypedDict(TypedDict):
    topic_id: str
    r"""Internal Topic ID of the notification"""
    topic_key: str
    r"""Topic Key of the notification"""


class ActivityTopicDto(BaseModel):
    topic_id: Annotated[str, pydantic.Field(alias="_topicId")]
    r"""Internal Topic ID of the notification"""

    topic_key: Annotated[str, pydantic.Field(alias="topicKey")]
    r"""Topic Key of the notification"""
