"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicDtoTypedDict(TypedDict):
    id: str
    r"""The internal unique identifier of the topic"""
    key: str
    r"""The key identifier of the topic used in your application. Should be unique on the environment level."""
    name: NotRequired[str]
    r"""The name of the topic"""


class TopicDto(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""The internal unique identifier of the topic"""

    key: str
    r"""The key identifier of the topic used in your application. Should be unique on the environment level."""

    name: Optional[str] = None
    r"""The name of the topic"""
