"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emailblockstyles import EmailBlockStyles, EmailBlockStylesTypedDict
from .emailblocktypeenum import EmailBlockTypeEnum
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class EmailBlockTypedDict(TypedDict):
    type: EmailBlockTypeEnum
    r"""Type of the email block"""
    content: str
    r"""Content of the email block"""
    url: NotRequired[str]
    r"""URL associated with the email block, if any"""
    styles: NotRequired[EmailBlockStylesTypedDict]
    r"""Styles applied to the email block"""


class EmailBlock(BaseModel):
    type: EmailBlockTypeEnum
    r"""Type of the email block"""

    content: str
    r"""Content of the email block"""

    url: Optional[str] = None
    r"""URL associated with the email block, if any"""

    styles: Optional[EmailBlockStyles] = None
    r"""Styles applied to the email block"""
