"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emaillayoutrenderoutput import (
    EmailLayoutRenderOutput,
    EmailLayoutRenderOutputTypedDict,
)
from .layoutpreviewpayloaddto import (
    LayoutPreviewPayloadDto,
    LayoutPreviewPayloadDtoTypedDict,
)
from enum import Enum
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ResultType(str, Enum):
    EMAIL = "email"


class OneTypedDict(TypedDict):
    type: NotRequired[ResultType]
    preview: NotRequired[EmailLayoutRenderOutputTypedDict]


class One(BaseModel):
    type: Optional[ResultType] = None

    preview: Optional[EmailLayoutRenderOutput] = None


ResultTypedDict = OneTypedDict
r"""Preview result"""


Result = One
r"""Preview result"""


class GenerateLayoutPreviewResponseDtoTypedDict(TypedDict):
    preview_payload_example: LayoutPreviewPayloadDtoTypedDict
    r"""Preview payload example"""
    result: ResultTypedDict
    r"""Preview result"""
    schema_: NotRequired[Nullable[Dict[str, Any]]]
    r"""The payload schema that was used to generate the preview payload example"""


class GenerateLayoutPreviewResponseDto(BaseModel):
    preview_payload_example: Annotated[
        LayoutPreviewPayloadDto, pydantic.Field(alias="previewPayloadExample")
    ]
    r"""Preview payload example"""

    result: Result
    r"""Preview result"""

    schema_: Annotated[
        OptionalNullable[Dict[str, Any]], pydantic.Field(alias="schema")
    ] = UNSET
    r"""The payload schema that was used to generate the preview payload example"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["schema"]
        nullable_fields = ["schema"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
