"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SeverityLevelEnum(str, Enum):
    r"""Severity of the workflow"""

    HIGH = "high"
    MEDIUM = "medium"
    LOW = "low"
    NONE = "none"
