"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ResourceTypeEnum(str, Enum):
    r"""Type of the layout"""

    REGULAR = "REGULAR"
    ECHO = "ECHO"
    BRIDGE = "BRIDGE"
