"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MessagesControllerDeleteMessagesByTransactionIDQueryParamChannel(str, Enum):
    r"""The channel of the message to be deleted"""

    IN_APP = "in_app"
    EMAIL = "email"
    SMS = "sms"
    CHAT = "chat"
    PUSH = "push"


class MessagesControllerDeleteMessagesByTransactionIDRequestTypedDict(TypedDict):
    transaction_id: str
    channel: NotRequired[
        MessagesControllerDeleteMessagesByTransactionIDQueryParamChannel
    ]
    r"""The channel of the message to be deleted"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class MessagesControllerDeleteMessagesByTransactionIDRequest(BaseModel):
    transaction_id: Annotated[
        str,
        pydantic.Field(alias="transactionId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    channel: Annotated[
        Optional[MessagesControllerDeleteMessagesByTransactionIDQueryParamChannel],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The channel of the message to be deleted"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class MessagesControllerDeleteMessagesByTransactionIDResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class MessagesControllerDeleteMessagesByTransactionIDResponse(BaseModel):
    headers: Dict[str, List[str]]
