"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .uischemagroupenum import UISchemaGroupEnum
from .uischemaproperty import UISchemaProperty, UISchemaPropertyTypedDict
from novu_py.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class UISchemaTypedDict(TypedDict):
    group: NotRequired[UISchemaGroupEnum]
    r"""Group of the UI Schema"""
    properties: NotRequired[Dict[str, UISchemaPropertyTypedDict]]
    r"""Properties of the UI Schema"""


class UISchema(BaseModel):
    group: Optional[UISchemaGroupEnum] = None
    r"""Group of the UI Schema"""

    properties: Optional[Dict[str, UISchemaProperty]] = None
    r"""Properties of the UI Schema"""
