"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createsubscriberrequestdto import (
    CreateSubscriberRequestDto,
    CreateSubscriberRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BulkSubscriberCreateDtoTypedDict(TypedDict):
    subscribers: List[CreateSubscriberRequestDtoTypedDict]
    r"""An array of subscribers to be created in bulk."""


class BulkSubscriberCreateDto(BaseModel):
    subscribers: List[CreateSubscriberRequestDto]
    r"""An array of subscribers to be created in bulk."""
