"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bulkupdatesubscriberpreferenceitemdto import (
    BulkUpdateSubscriberPreferenceItemDto,
    BulkUpdateSubscriberPreferenceItemDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BulkUpdateSubscriberPreferencesDtoTypedDict(TypedDict):
    preferences: List[BulkUpdateSubscriberPreferenceItemDtoTypedDict]
    r"""Array of workflow preferences to update (maximum 100 items)"""


class BulkUpdateSubscriberPreferencesDto(BaseModel):
    preferences: List[BulkUpdateSubscriberPreferenceItemDto]
    r"""Array of workflow preferences to update (maximum 100 items)"""
