"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ChannelPreferenceDtoTypedDict(TypedDict):
    enabled: NotRequired[bool]
    r"""A flag specifying if notification delivery is enabled for the channel. If true, notification delivery is enabled."""


class ChannelPreferenceDto(BaseModel):
    enabled: Optional[bool] = True
    r"""A flag specifying if notification delivery is enabled for the channel. If true, notification delivery is enabled."""
