"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .buttontypeenum import ButtonTypeEnum
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class MessageButtonTypedDict(TypedDict):
    type: ButtonTypeEnum
    r"""Type of button for the action result"""
    content: str
    r"""Content of the button"""
    result_content: NotRequired[str]
    r"""Content of the result when the button is clicked"""


class MessageButton(BaseModel):
    type: ButtonTypeEnum
    r"""Type of button for the action result"""

    content: str
    r"""Content of the button"""

    result_content: Annotated[Optional[str], pydantic.Field(alias="resultContent")] = (
        None
    )
    r"""Content of the result when the button is clicked"""
