"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberpreferencechannels import (
    SubscriberPreferenceChannels,
    SubscriberPreferenceChannelsTypedDict,
)
from .subscriberpreferenceoverridedto import (
    SubscriberPreferenceOverrideDto,
    SubscriberPreferenceOverrideDtoTypedDict,
)
from .subscriberpreferencesworkflowinfodto import (
    SubscriberPreferencesWorkflowInfoDto,
    SubscriberPreferencesWorkflowInfoDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SubscriberWorkflowPreferenceDtoTypedDict(TypedDict):
    enabled: bool
    r"""Whether notifications are enabled for this workflow"""
    channels: SubscriberPreferenceChannelsTypedDict
    r"""Channel-specific preference settings for this workflow"""
    overrides: List[SubscriberPreferenceOverrideDtoTypedDict]
    r"""List of preference overrides"""
    workflow: SubscriberPreferencesWorkflowInfoDtoTypedDict
    r"""Workflow information"""


class SubscriberWorkflowPreferenceDto(BaseModel):
    enabled: bool
    r"""Whether notifications are enabled for this workflow"""

    channels: SubscriberPreferenceChannels
    r"""Channel-specific preference settings for this workflow"""

    overrides: List[SubscriberPreferenceOverrideDto]
    r"""List of preference overrides"""

    workflow: SubscriberPreferencesWorkflowInfoDto
    r"""Workflow information"""
