"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConfigurationsDtoTypedDict(TypedDict):
    inbound_webhook_enabled: NotRequired[bool]
    inbound_webhook_signing_key: NotRequired[str]


class ConfigurationsDto(BaseModel):
    inbound_webhook_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="inboundWebhookEnabled")
    ] = None

    inbound_webhook_signing_key: Annotated[
        Optional[str], pydantic.Field(alias="inboundWebhookSigningKey")
    ] = None
