"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getsubscriberpreferencesdto import (
    GetSubscriberPreferencesDto,
    GetSubscriberPreferencesDtoTypedDict,
)
from enum import Enum
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class Criticality(str, Enum):
    CRITICAL = "critical"
    NON_CRITICAL = "nonCritical"
    ALL = "all"


class SubscribersControllerGetSubscriberPreferencesRequestTypedDict(TypedDict):
    subscriber_id: str
    criticality: NotRequired[Criticality]
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class SubscribersControllerGetSubscriberPreferencesRequest(BaseModel):
    subscriber_id: Annotated[
        str,
        pydantic.Field(alias="subscriberId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    criticality: Annotated[
        Optional[Criticality],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = Criticality.NON_CRITICAL

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class SubscribersControllerGetSubscriberPreferencesResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetSubscriberPreferencesDtoTypedDict


class SubscribersControllerGetSubscriberPreferencesResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetSubscriberPreferencesDto
