"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class MsTeamsChannelEndpointDtoTypedDict(TypedDict):
    team_id: str
    r"""MS Teams team ID"""
    channel_id: str
    r"""MS Teams channel ID"""


class MsTeamsChannelEndpointDto(BaseModel):
    team_id: Annotated[str, pydantic.Field(alias="teamId")]
    r"""MS Teams team ID"""

    channel_id: Annotated[str, pydantic.Field(alias="channelId")]
    r"""MS Teams channel ID"""
