"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateEnvironmentRequestDtoTypedDict(TypedDict):
    name: str
    r"""Name of the environment to be created"""
    color: str
    r"""Hex color code for the environment"""
    parent_id: NotRequired[str]
    r"""MongoDB ObjectId of the parent environment (optional)"""


class CreateEnvironmentRequestDto(BaseModel):
    name: str
    r"""Name of the environment to be created"""

    color: str
    r"""Hex color code for the environment"""

    parent_id: Annotated[Optional[str], pydantic.Field(alias="parentId")] = None
    r"""MongoDB ObjectId of the parent environment (optional)"""
