"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ReplyCallbackTypedDict(TypedDict):
    active: NotRequired[bool]
    r"""Indicates whether the reply callback is active."""
    url: NotRequired[str]
    r"""The URL to which replies should be sent."""


class ReplyCallback(BaseModel):
    active: Optional[bool] = None
    r"""Indicates whether the reply callback is active."""

    url: Optional[str] = None
    r"""The URL to which replies should be sent."""
