"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ExecutionDetailsSourceEnum(str, Enum):
    r"""Source of the execution detail"""

    CREDENTIALS = "Credentials"
    INTERNAL = "Internal"
    PAYLOAD = "Payload"
    WEBHOOK = "Webhook"
