"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resourceoriginenum import ResourceOriginEnum
from .stepissuesdto import StepIssuesDto, StepIssuesDtoTypedDict
from .steptypeenum import StepTypeEnum
from .throttlecontrolsmetadataresponsedto import (
    ThrottleControlsMetadataResponseDto,
    ThrottleControlsMetadataResponseDtoTypedDict,
)
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from pydantic import ConfigDict
from typing import Any, Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ThrottleStepResponseDtoType(str, Enum):
    r"""The type of throttle window."""

    FIXED = "fixed"
    DYNAMIC = "dynamic"


class ThrottleStepResponseDtoUnit(str, Enum):
    r"""The unit of time for the throttle window (required for fixed type)."""

    MINUTES = "minutes"
    HOURS = "hours"
    DAYS = "days"


class ThrottleStepResponseDtoControlValuesTypedDict(TypedDict):
    r"""Control values for the throttle step"""

    skip: NotRequired[Dict[str, Any]]
    r"""JSONLogic filter conditions for conditionally skipping the step execution. Supports complex logical operations with AND, OR, and comparison operators. See https://jsonlogic.com/ for full typing reference."""
    type: NotRequired[ThrottleStepResponseDtoType]
    r"""The type of throttle window."""
    amount: NotRequired[float]
    r"""The amount of time for the throttle window (required for fixed type)."""
    unit: NotRequired[ThrottleStepResponseDtoUnit]
    r"""The unit of time for the throttle window (required for fixed type)."""
    dynamic_key: NotRequired[str]
    r"""Key path to retrieve dynamic window value (required for dynamic type)."""
    threshold: NotRequired[float]
    r"""The maximum number of executions allowed within the window. Defaults to 1."""
    throttle_key: NotRequired[str]
    r"""Optional key for grouping throttle rules. If not provided, defaults to workflow and subscriber combination."""


class ThrottleStepResponseDtoControlValues(BaseModel):
    r"""Control values for the throttle step"""

    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Any] = pydantic.Field(init=False)

    skip: Optional[Dict[str, Any]] = None
    r"""JSONLogic filter conditions for conditionally skipping the step execution. Supports complex logical operations with AND, OR, and comparison operators. See https://jsonlogic.com/ for full typing reference."""

    type: Optional[ThrottleStepResponseDtoType] = ThrottleStepResponseDtoType.FIXED
    r"""The type of throttle window."""

    amount: Optional[float] = None
    r"""The amount of time for the throttle window (required for fixed type)."""

    unit: Optional[ThrottleStepResponseDtoUnit] = None
    r"""The unit of time for the throttle window (required for fixed type)."""

    dynamic_key: Annotated[Optional[str], pydantic.Field(alias="dynamicKey")] = None
    r"""Key path to retrieve dynamic window value (required for dynamic type)."""

    threshold: Optional[float] = 1
    r"""The maximum number of executions allowed within the window. Defaults to 1."""

    throttle_key: Annotated[Optional[str], pydantic.Field(alias="throttleKey")] = None
    r"""Optional key for grouping throttle rules. If not provided, defaults to workflow and subscriber combination."""

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]


class ThrottleStepResponseDtoTypedDict(TypedDict):
    controls: ThrottleControlsMetadataResponseDtoTypedDict
    r"""Controls metadata for the throttle step"""
    variables: Dict[str, Any]
    r"""JSON Schema for variables, follows the JSON Schema standard"""
    step_id: str
    r"""Unique identifier of the step"""
    id: str
    r"""Database identifier of the step"""
    name: str
    r"""Name of the step"""
    slug: str
    r"""Slug of the step"""
    type: StepTypeEnum
    r"""Type of the step"""
    origin: ResourceOriginEnum
    r"""Origin of the layout"""
    workflow_id: str
    r"""Workflow identifier"""
    workflow_database_id: str
    r"""Workflow database identifier"""
    control_values: NotRequired[ThrottleStepResponseDtoControlValuesTypedDict]
    r"""Control values for the throttle step"""
    issues: NotRequired[StepIssuesDtoTypedDict]
    r"""Issues associated with the step"""


class ThrottleStepResponseDto(BaseModel):
    controls: ThrottleControlsMetadataResponseDto
    r"""Controls metadata for the throttle step"""

    variables: Dict[str, Any]
    r"""JSON Schema for variables, follows the JSON Schema standard"""

    step_id: Annotated[str, pydantic.Field(alias="stepId")]
    r"""Unique identifier of the step"""

    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""Database identifier of the step"""

    name: str
    r"""Name of the step"""

    slug: str
    r"""Slug of the step"""

    type: StepTypeEnum
    r"""Type of the step"""

    origin: ResourceOriginEnum
    r"""Origin of the layout"""

    workflow_id: Annotated[str, pydantic.Field(alias="workflowId")]
    r"""Workflow identifier"""

    workflow_database_id: Annotated[str, pydantic.Field(alias="workflowDatabaseId")]
    r"""Workflow database identifier"""

    control_values: Annotated[
        Optional[ThrottleStepResponseDtoControlValues],
        pydantic.Field(alias="controlValues"),
    ] = None
    r"""Control values for the throttle step"""

    issues: Optional[StepIssuesDto] = None
    r"""Issues associated with the step"""
