"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LayoutResponseDtoSortField(str, Enum):
    CREATED_AT = "createdAt"
    UPDATED_AT = "updatedAt"
    NAME = "name"
