"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicSubscriberIdentifierDtoTypedDict(TypedDict):
    identifier: str
    r"""Unique identifier for this subscription"""
    subscriber_id: str
    r"""The subscriber ID"""
    name: NotRequired[str]
    r"""The name of the subscription"""


class TopicSubscriberIdentifierDto(BaseModel):
    identifier: str
    r"""Unique identifier for this subscription"""

    subscriber_id: Annotated[str, pydantic.Field(alias="subscriberId")]
    r"""The subscriber ID"""

    name: Optional[str] = None
    r"""The name of the subscription"""
