"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class UpdatedSubscriberDtoTypedDict(TypedDict):
    subscriber_id: str
    r"""The ID of the subscriber that was updated."""


class UpdatedSubscriberDto(BaseModel):
    subscriber_id: Annotated[str, pydantic.Field(alias="subscriberId")]
    r"""The ID of the subscriber that was updated."""
