"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .triggereventrequestdto import (
    TriggerEventRequestDto,
    TriggerEventRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BulkTriggerEventDtoTypedDict(TypedDict):
    events: List[TriggerEventRequestDtoTypedDict]


class BulkTriggerEventDto(BaseModel):
    events: List[TriggerEventRequestDto]
