"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict
from typing_extensions import Annotated, TypedDict


class GetContextResponseDtoTypedDict(TypedDict):
    type: str
    r"""Context type (e.g., tenant, app, workspace)"""
    id: str
    r"""Unique identifier for this context"""
    data: Dict[str, Any]
    r"""Custom data associated with this context"""
    created_at: str
    r"""Creation timestamp"""
    updated_at: str
    r"""Last update timestamp"""


class GetContextResponseDto(BaseModel):
    type: str
    r"""Context type (e.g., tenant, app, workspace)"""

    id: str
    r"""Unique identifier for this context"""

    data: Dict[str, Any]
    r"""Custom data associated with this context"""

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]
    r"""Creation timestamp"""

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]
    r"""Last update timestamp"""
