"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .authdto import AuthDto, AuthDtoTypedDict
from .workspacedto import WorkspaceDto, WorkspaceDtoTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateChannelConnectionRequestDtoTypedDict(TypedDict):
    workspace: WorkspaceDtoTypedDict
    auth: AuthDtoTypedDict


class UpdateChannelConnectionRequestDto(BaseModel):
    workspace: WorkspaceDto

    auth: AuthDto
