"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ButtonTypeEnum(str, Enum):
    r"""Type of button for the action result"""

    PRIMARY = "primary"
    SECONDARY = "secondary"
