"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict
from typing_extensions import Annotated, TypedDict


class ImportMasterJSONRequestDtoTypedDict(TypedDict):
    locale: str
    r"""The locale for which translations are being imported"""
    master_json: Dict[str, Any]
    r"""Master JSON object containing all translations organized by workflow identifier"""


class ImportMasterJSONRequestDto(BaseModel):
    locale: str
    r"""The locale for which translations are being imported"""

    master_json: Annotated[Dict[str, Any], pydantic.Field(alias="masterJson")]
    r"""Master JSON object containing all translations organized by workflow identifier"""
