"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DeleteMessageResponseDtoStatus(str, Enum):
    r"""The status enum for the performed action"""

    DELETED = "deleted"


class DeleteMessageResponseDtoTypedDict(TypedDict):
    acknowledged: bool
    r"""A boolean stating the success of the action"""
    status: DeleteMessageResponseDtoStatus
    r"""The status enum for the performed action"""


class DeleteMessageResponseDto(BaseModel):
    acknowledged: bool
    r"""A boolean stating the success of the action"""

    status: DeleteMessageResponseDtoStatus
    r"""The status enum for the performed action"""
