"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class InBoundParseDomainDtoTypedDict(TypedDict):
    inbound_parse_domain: NotRequired[str]


class InBoundParseDomainDto(BaseModel):
    inbound_parse_domain: Annotated[
        Optional[str], pydantic.Field(alias="inboundParseDomain")
    ] = None
