"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .patchpreferencechannelsdto import (
    PatchPreferenceChannelsDto,
    PatchPreferenceChannelsDtoTypedDict,
)
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class BulkUpdateSubscriberPreferenceItemDtoTypedDict(TypedDict):
    channels: PatchPreferenceChannelsDtoTypedDict
    r"""Channel-specific preference settings"""
    workflow_id: str
    r"""Workflow internal _id, identifier or slug"""


class BulkUpdateSubscriberPreferenceItemDto(BaseModel):
    channels: PatchPreferenceChannelsDto
    r"""Channel-specific preference settings"""

    workflow_id: Annotated[str, pydantic.Field(alias="workflowId")]
    r"""Workflow internal _id, identifier or slug"""
