"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class BuilderFieldTypeEnum(str, Enum):
    BOOLEAN = "BOOLEAN"
    TEXT = "TEXT"
    DATE = "DATE"
    NUMBER = "NUMBER"
    STATEMENT = "STATEMENT"
    LIST = "LIST"
    MULTI_LIST = "MULTI_LIST"
    GROUP = "GROUP"
