"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ActorTypeEnum(str, Enum):
    r"""The type of the actor, indicating the role in the notification process."""

    NONE = "none"
    USER = "user"
    SYSTEM_ICON = "system_icon"
    SYSTEM_CUSTOM = "system_custom"
