"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .topicsubscriptionresponsedto import (
    TopicSubscriptionResponseDto,
    TopicSubscriptionResponseDtoTypedDict,
)
from novu_py.types import BaseModel, Nullable, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List
from typing_extensions import Annotated, TypedDict


class ListTopicSubscriptionsResponseDtoTypedDict(TypedDict):
    data: List[TopicSubscriptionResponseDtoTypedDict]
    r"""List of returned Topic Subscriptions"""
    next: Nullable[str]
    r"""The cursor for the next page of results, or null if there are no more pages."""
    previous: Nullable[str]
    r"""The cursor for the previous page of results, or null if this is the first page."""
    total_count: float
    r"""The total count of items (up to 50,000)"""
    total_count_capped: bool
    r"""Whether there are more than 50,000 results available"""


class ListTopicSubscriptionsResponseDto(BaseModel):
    data: List[TopicSubscriptionResponseDto]
    r"""List of returned Topic Subscriptions"""

    next: Nullable[str]
    r"""The cursor for the next page of results, or null if there are no more pages."""

    previous: Nullable[str]
    r"""The cursor for the previous page of results, or null if this is the first page."""

    total_count: Annotated[float, pydantic.Field(alias="totalCount")]
    r"""The total count of items (up to 50,000)"""

    total_count_capped: Annotated[bool, pydantic.Field(alias="totalCountCapped")]
    r"""Whether there are more than 50,000 results available"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["next", "previous"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
