"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .scheduledto import ScheduleDto, ScheduleDtoTypedDict
from .subscriberpreferencechannels import (
    SubscriberPreferenceChannels,
    SubscriberPreferenceChannelsTypedDict,
)
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SubscriberGlobalPreferenceDtoTypedDict(TypedDict):
    enabled: bool
    r"""Whether notifications are enabled globally"""
    channels: SubscriberPreferenceChannelsTypedDict
    r"""Channel-specific preference settings"""
    schedule: NotRequired[ScheduleDtoTypedDict]
    r"""Subscriber schedule"""


class SubscriberGlobalPreferenceDto(BaseModel):
    enabled: bool
    r"""Whether notifications are enabled globally"""

    channels: SubscriberPreferenceChannels
    r"""Channel-specific preference settings"""

    schedule: Optional[ScheduleDto] = None
    r"""Subscriber schedule"""
