"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bridgeconfigurationdto import (
    BridgeConfigurationDto,
    BridgeConfigurationDtoTypedDict,
)
from .inboundparsedomaindto import InBoundParseDomainDto, InBoundParseDomainDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateEnvironmentRequestDtoTypedDict(TypedDict):
    name: NotRequired[str]
    identifier: NotRequired[str]
    parent_id: NotRequired[str]
    color: NotRequired[str]
    dns: NotRequired[InBoundParseDomainDtoTypedDict]
    bridge: NotRequired[BridgeConfigurationDtoTypedDict]


class UpdateEnvironmentRequestDto(BaseModel):
    name: Optional[str] = None

    identifier: Optional[str] = None

    parent_id: Annotated[Optional[str], pydantic.Field(alias="parentId")] = None

    color: Optional[str] = None

    dns: Optional[InBoundParseDomainDto] = None

    bridge: Optional[BridgeConfigurationDto] = None
