"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class TextAlignEnum(str, Enum):
    r"""Text alignment for the email block"""

    CENTER = "center"
    LEFT = "left"
    RIGHT = "right"
