"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class BridgeConfigurationDtoTypedDict(TypedDict):
    url: NotRequired[str]


class BridgeConfigurationDto(BaseModel):
    url: Optional[str] = None
