"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MessageActionStatusEnum(str, Enum):
    r"""Status of the message action"""

    PENDING = "pending"
    DONE = "done"
