"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getchannelendpointresponsedto import (
    GetChannelEndpointResponseDto,
    GetChannelEndpointResponseDtoTypedDict,
)
from .updatechannelendpointrequestdto import (
    UpdateChannelEndpointRequestDto,
    UpdateChannelEndpointRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChannelEndpointsControllerUpdateChannelEndpointRequestTypedDict(TypedDict):
    identifier: str
    r"""The unique identifier of the channel endpoint"""
    update_channel_endpoint_request_dto: UpdateChannelEndpointRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class ChannelEndpointsControllerUpdateChannelEndpointRequest(BaseModel):
    identifier: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""The unique identifier of the channel endpoint"""

    update_channel_endpoint_request_dto: Annotated[
        UpdateChannelEndpointRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class ChannelEndpointsControllerUpdateChannelEndpointResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetChannelEndpointResponseDtoTypedDict


class ChannelEndpointsControllerUpdateChannelEndpointResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetChannelEndpointResponseDto
