"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class MonthlyTypeEnum(str, Enum):
    r"""Type of monthly schedule"""

    EACH = "each"
    ON = "on"
