"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createdsubscriberdto import CreatedSubscriberDto, CreatedSubscriberDtoTypedDict
from .failedoperationdto import FailedOperationDto, FailedOperationDtoTypedDict
from .updatedsubscriberdto import UpdatedSubscriberDto, UpdatedSubscriberDtoTypedDict
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BulkCreateSubscriberResponseDtoTypedDict(TypedDict):
    updated: List[UpdatedSubscriberDtoTypedDict]
    r"""An array of subscribers that were successfully updated."""
    created: List[CreatedSubscriberDtoTypedDict]
    r"""An array of subscribers that were successfully created."""
    failed: List[FailedOperationDtoTypedDict]
    r"""An array of failed operations with error messages and optional subscriber IDs."""


class BulkCreateSubscriberResponseDto(BaseModel):
    updated: List[UpdatedSubscriberDto]
    r"""An array of subscribers that were successfully updated."""

    created: List[CreatedSubscriberDto]
    r"""An array of subscribers that were successfully created."""

    failed: List[FailedOperationDto]
    r"""An array of failed operations with error messages and optional subscriber IDs."""
