"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .channeltypeenum import ChannelTypeEnum
from .preferenceoverridesourceenum import PreferenceOverrideSourceEnum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class SubscriberPreferenceOverrideDtoTypedDict(TypedDict):
    channel: ChannelTypeEnum
    r"""Channel type through which the message is sent"""
    source: PreferenceOverrideSourceEnum
    r"""The source of overrides"""


class SubscriberPreferenceOverrideDto(BaseModel):
    channel: ChannelTypeEnum
    r"""Channel type through which the message is sent"""

    source: PreferenceOverrideSourceEnum
    r"""The source of overrides"""
