"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createchannelconnectionrequestdto import (
    CreateChannelConnectionRequestDto,
    CreateChannelConnectionRequestDtoTypedDict,
)
from .getchannelconnectionresponsedto import (
    GetChannelConnectionResponseDto,
    GetChannelConnectionResponseDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ChannelConnectionsControllerCreateChannelConnectionRequestTypedDict(TypedDict):
    create_channel_connection_request_dto: CreateChannelConnectionRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class ChannelConnectionsControllerCreateChannelConnectionRequest(BaseModel):
    create_channel_connection_request_dto: Annotated[
        CreateChannelConnectionRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class ChannelConnectionsControllerCreateChannelConnectionResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetChannelConnectionResponseDtoTypedDict


class ChannelConnectionsControllerCreateChannelConnectionResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetChannelConnectionResponseDto
