"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteTopicSubscriberIdentifierDtoTypedDict(TypedDict):
    identifier: NotRequired[str]
    r"""Unique identifier for this subscription. If provided, deletes only this specific subscription."""
    subscriber_id: NotRequired[str]
    r"""The subscriber ID. If provided without identifier, deletes all subscriptions for this subscriber within the topic."""


class DeleteTopicSubscriberIdentifierDto(BaseModel):
    identifier: Optional[str] = None
    r"""Unique identifier for this subscription. If provided, deletes only this specific subscription."""

    subscriber_id: Annotated[Optional[str], pydantic.Field(alias="subscriberId")] = None
    r"""The subscriber ID. If provided without identifier, deletes all subscriptions for this subscriber within the topic."""
