"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class LookBackWindowDtoUnit(str, Enum):
    r"""Unit of time for the look-back window."""

    SECONDS = "seconds"
    MINUTES = "minutes"
    HOURS = "hours"
    DAYS = "days"
    WEEKS = "weeks"
    MONTHS = "months"


class LookBackWindowDtoTypedDict(TypedDict):
    amount: float
    r"""Amount of time for the look-back window."""
    unit: LookBackWindowDtoUnit
    r"""Unit of time for the look-back window."""


class LookBackWindowDto(BaseModel):
    amount: float
    r"""Amount of time for the look-back window."""

    unit: LookBackWindowDtoUnit
    r"""Unit of time for the look-back window."""
