"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class SubscriptionsDeleteErrorDtoTypedDict(TypedDict):
    subscriber_id: str
    r"""The subscriber ID that failed"""
    code: str
    r"""The error code"""
    message: str
    r"""The error message"""


class SubscriptionsDeleteErrorDto(BaseModel):
    subscriber_id: Annotated[str, pydantic.Field(alias="subscriberId")]
    r"""The subscriber ID that failed"""

    code: str
    r"""The error code"""

    message: str
    r"""The error message"""
