"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GroupPreferenceFilterDetailsDtoTypedDict(TypedDict):
    workflow_ids: NotRequired[List[str]]
    r"""List of workflow identifiers"""
    tags: NotRequired[List[str]]
    r"""List of tags"""


class GroupPreferenceFilterDetailsDto(BaseModel):
    workflow_ids: Annotated[
        Optional[List[str]], pydantic.Field(alias="workflowIds")
    ] = None
    r"""List of workflow identifiers"""

    tags: Optional[List[str]] = None
    r"""List of tags"""
