"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class WorkflowCreationSourceEnum(str, Enum):
    r"""Source of workflow creation"""

    TEMPLATE_STORE = "template_store"
    EDITOR = "editor"
    NOTIFICATION_DIRECTORY = "notification_directory"
    ONBOARDING_DIGEST_DEMO = "onboarding_digest_demo"
    ONBOARDING_IN_APP = "onboarding_in_app"
    EMPTY_STATE = "empty_state"
    DROPDOWN = "dropdown"
    ONBOARDING_GET_STARTED = "onboarding_get_started"
    BRIDGE = "bridge"
    DASHBOARD = "dashboard"
