"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class APIKeyDtoTypedDict(TypedDict):
    key: str
    r"""API key"""
    user_id: str
    r"""User ID associated with the API key"""
    hash: NotRequired[str]
    r"""Hashed representation of the API key"""


class APIKeyDto(BaseModel):
    key: str
    r"""API key"""

    user_id: Annotated[str, pydantic.Field(alias="_userId")]
    r"""User ID associated with the API key"""

    hash: Optional[str] = None
    r"""Hashed representation of the API key"""
