"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .unseencountresponse import UnseenCountResponse, UnseenCountResponseTypedDict
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    QueryParamMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SubscribersV1ControllerGetUnseenCountRequestTypedDict(TypedDict):
    subscriber_id: str
    seen: NotRequired[bool]
    r"""Indicates whether to count seen notifications."""
    limit: NotRequired[float]
    r"""The maximum number of notifications to return."""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerGetUnseenCountRequest(BaseModel):
    subscriber_id: Annotated[
        str,
        pydantic.Field(alias="subscriberId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    seen: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = False
    r"""Indicates whether to count seen notifications."""

    limit: Annotated[
        Optional[float],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 100
    r"""The maximum number of notifications to return."""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class SubscribersV1ControllerGetUnseenCountResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: UnseenCountResponseTypedDict


class SubscribersV1ControllerGetUnseenCountResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: UnseenCountResponse
