"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stepissuesdto import StepIssuesDto, StepIssuesDtoTypedDict
from .steptypeenum import StepTypeEnum
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class StepListResponseDtoTypedDict(TypedDict):
    slug: str
    r"""Slug of the step"""
    type: StepTypeEnum
    r"""Type of the step"""
    issues: NotRequired[StepIssuesDtoTypedDict]
    r"""Issues associated with the step"""


class StepListResponseDto(BaseModel):
    slug: str
    r"""Slug of the step"""

    type: StepTypeEnum
    r"""Type of the step"""

    issues: Optional[StepIssuesDto] = None
    r"""Issues associated with the step"""
