"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class SyncWorkflowDtoTypedDict(TypedDict):
    target_environment_id: str
    r"""Target environment identifier to sync the workflow to"""


class SyncWorkflowDto(BaseModel):
    target_environment_id: Annotated[str, pydantic.Field(alias="targetEnvironmentId")]
    r"""Target environment identifier to sync the workflow to"""
