"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PreferenceOverrideSourceEnum(str, Enum):
    r"""The source of overrides"""

    SUBSCRIBER = "subscriber"
    TEMPLATE = "template"
    WORKFLOW_OVERRIDE = "workflowOverride"
