"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WebhookEndpointDtoTypedDict(TypedDict):
    url: str
    r"""Webhook URL"""
    channel: NotRequired[str]
    r"""Optional channel identifier"""


class WebhookEndpointDto(BaseModel):
    url: str
    r"""Webhook URL"""

    channel: Optional[str] = None
    r"""Optional channel identifier"""
