"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class DigestTypeEnum(str, Enum):
    r"""The Digest Type"""

    REGULAR = "regular"
    BACKOFF = "backoff"
    TIMED = "timed"
