"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .eventbody import EventBody, EventBodyTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class WebhookResultDtoTypedDict(TypedDict):
    id: str
    r"""Unique identifier for the webhook result"""
    event: EventBodyTypedDict
    r"""Event body containing the webhook event data"""


class WebhookResultDto(BaseModel):
    id: str
    r"""Unique identifier for the webhook result"""

    event: EventBody
    r"""Event body containing the webhook event data"""
