"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IntegrationTypedDict(TypedDict):
    r"""The updated configurations after auto-configuration"""


class Integration(BaseModel):
    r"""The updated configurations after auto-configuration"""


class AutoConfigureIntegrationResponseDtoTypedDict(TypedDict):
    success: bool
    r"""Indicates whether the auto-configuration was successful"""
    message: NotRequired[str]
    r"""Optional message describing the result or any errors that occurred"""
    integration: NotRequired[IntegrationTypedDict]
    r"""The updated configurations after auto-configuration"""


class AutoConfigureIntegrationResponseDto(BaseModel):
    success: bool
    r"""Indicates whether the auto-configuration was successful"""

    message: Optional[str] = None
    r"""Optional message describing the result or any errors that occurred"""

    integration: Optional[Integration] = None
    r"""The updated configurations after auto-configuration"""
