"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .redirectdto import RedirectDto, RedirectDtoTypedDict
from novu_py.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ActionDtoTypedDict(TypedDict):
    label: NotRequired[str]
    r"""Label for the action button."""
    redirect: NotRequired[RedirectDtoTypedDict]
    r"""Redirect configuration for the action."""


class ActionDto(BaseModel):
    label: Optional[str] = None
    r"""Label for the action button."""

    redirect: Optional[RedirectDto] = None
    r"""Redirect configuration for the action."""
