"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class PreferenceLevelEnum(str, Enum):
    r"""The level of the preference (global or template)"""

    GLOBAL = "global"
    TEMPLATE = "template"
