"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class FailedOperationDtoTypedDict(TypedDict):
    message: NotRequired[str]
    r"""The error message associated with the failed operation."""
    subscriber_id: NotRequired[str]
    r"""The subscriber ID associated with the failed operation. This field is optional."""


class FailedOperationDto(BaseModel):
    message: Optional[str] = None
    r"""The error message associated with the failed operation."""

    subscriber_id: Annotated[Optional[str], pydantic.Field(alias="subscriberId")] = None
    r"""The subscriber ID associated with the failed operation. This field is optional."""
