"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ImportMasterJSONResponseDtoTypedDict(TypedDict):
    success: bool
    r"""Overall success status of the import operation"""
    message: str
    r"""Human-readable message describing the import result"""
    successful: NotRequired[List[str]]
    r"""List of resource IDs that were successfully imported"""
    failed: NotRequired[List[str]]
    r"""List of resource IDs that failed to import"""


class ImportMasterJSONResponseDto(BaseModel):
    success: bool
    r"""Overall success status of the import operation"""

    message: str
    r"""Human-readable message describing the import result"""

    successful: Optional[List[str]] = None
    r"""List of resource IDs that were successfully imported"""

    failed: Optional[List[str]] = None
    r"""List of resource IDs that failed to import"""
