"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .activitynotificationresponsedto import (
    ActivityNotificationResponseDto,
    ActivityNotificationResponseDtoTypedDict,
)
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ActivitiesResponseDtoTypedDict(TypedDict):
    has_more: bool
    r"""Indicates if there are more activities in the result set"""
    data: List[ActivityNotificationResponseDtoTypedDict]
    r"""Array of activity notifications"""
    page_size: float
    r"""Page size of the activities"""
    page: float
    r"""Current page of the activities"""


class ActivitiesResponseDto(BaseModel):
    has_more: Annotated[bool, pydantic.Field(alias="hasMore")]
    r"""Indicates if there are more activities in the result set"""

    data: List[ActivityNotificationResponseDto]
    r"""Array of activity notifications"""

    page_size: Annotated[float, pydantic.Field(alias="pageSize")]
    r"""Page size of the activities"""

    page: float
    r"""Current page of the activities"""
