"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .createlayoutdto import CreateLayoutDto, CreateLayoutDtoTypedDict
from .layoutresponsedto import LayoutResponseDto, LayoutResponseDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class LayoutsControllerCreateRequestTypedDict(TypedDict):
    create_layout_dto: CreateLayoutDtoTypedDict
    r"""Layout creation details"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class LayoutsControllerCreateRequest(BaseModel):
    create_layout_dto: Annotated[
        CreateLayoutDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Layout creation details"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class LayoutsControllerCreateResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: LayoutResponseDtoTypedDict


class LayoutsControllerCreateResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: LayoutResponseDto
