"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SubscriberPreferencesWorkflowInfoDtoTypedDict(TypedDict):
    slug: str
    r"""Workflow slug"""
    identifier: str
    r"""Unique identifier of the workflow"""
    name: str
    r"""Display name of the workflow"""
    updated_at: NotRequired[str]
    r"""last updated date"""


class SubscriberPreferencesWorkflowInfoDto(BaseModel):
    slug: str
    r"""Workflow slug"""

    identifier: str
    r"""Unique identifier of the workflow"""

    name: str
    r"""Display name of the workflow"""

    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None
    r"""last updated date"""
