"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class AuthDtoTypedDict(TypedDict):
    access_token: str


class AuthDto(BaseModel):
    access_token: Annotated[str, pydantic.Field(alias="accessToken")]
