"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from novu_py.models import NovuError
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated


class TopicResponseDtoErrorData(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""The identifier of the topic"""
    key: str
    r"""The unique key of the topic"""
    name: Optional[str] = None
    r"""The name of the topic"""
    created_at: Annotated[Optional[str], pydantic.Field(alias="createdAt")] = None
    r"""The date the topic was created"""
    updated_at: Annotated[Optional[str], pydantic.Field(alias="updatedAt")] = None
    r"""The date the topic was last updated"""


@dataclass(unsafe_hash=True)
class TopicResponseDtoError(NovuError):
    data: TopicResponseDtoErrorData = field(hash=False)

    def __init__(
        self,
        data: TopicResponseDtoErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)
