"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WorkflowInfoDtoTypedDict(TypedDict):
    name: str
    r"""The name of the workflow"""
    workflow_id: str
    r"""The unique identifier of the workflow"""


class WorkflowInfoDto(BaseModel):
    name: str
    r"""The name of the workflow"""

    workflow_id: Annotated[str, pydantic.Field(alias="workflowId")]
    r"""The unique identifier of the workflow"""
