"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ResourceOriginEnum(str, Enum):
    r"""Origin of the layout"""

    NOVU_CLOUD = "novu-cloud"
    NOVU_CLOUD_V1 = "novu-cloud-v1"
    EXTERNAL = "external"
