"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class UIComponentEnum(str, Enum):
    r"""Component type for the UI Schema Property"""

    EMAIL_EDITOR_SELECT = "EMAIL_EDITOR_SELECT"
    LAYOUT_SELECT = "LAYOUT_SELECT"
    BLOCK_EDITOR = "BLOCK_EDITOR"
    EMAIL_BODY = "EMAIL_BODY"
    TEXT_FULL_LINE = "TEXT_FULL_LINE"
    TEXT_INLINE_LABEL = "TEXT_INLINE_LABEL"
    IN_APP_BODY = "IN_APP_BODY"
    IN_APP_AVATAR = "IN_APP_AVATAR"
    IN_APP_PRIMARY_SUBJECT = "IN_APP_PRIMARY_SUBJECT"
    IN_APP_BUTTON_DROPDOWN = "IN_APP_BUTTON_DROPDOWN"
    IN_APP_DISABLE_SANITIZATION_SWITCH = "IN_APP_DISABLE_SANITIZATION_SWITCH"
    DISABLE_SANITIZATION_SWITCH = "DISABLE_SANITIZATION_SWITCH"
    URL_TEXT_BOX = "URL_TEXT_BOX"
    DIGEST_AMOUNT = "DIGEST_AMOUNT"
    DIGEST_UNIT = "DIGEST_UNIT"
    DIGEST_TYPE = "DIGEST_TYPE"
    DIGEST_KEY = "DIGEST_KEY"
    DIGEST_CRON = "DIGEST_CRON"
    DELAY_AMOUNT = "DELAY_AMOUNT"
    DELAY_UNIT = "DELAY_UNIT"
    DELAY_TYPE = "DELAY_TYPE"
    DELAY_CRON = "DELAY_CRON"
    DELAY_DYNAMIC_KEY = "DELAY_DYNAMIC_KEY"
    THROTTLE_TYPE = "THROTTLE_TYPE"
    THROTTLE_WINDOW = "THROTTLE_WINDOW"
    THROTTLE_UNIT = "THROTTLE_UNIT"
    THROTTLE_DYNAMIC_KEY = "THROTTLE_DYNAMIC_KEY"
    THROTTLE_THRESHOLD = "THROTTLE_THRESHOLD"
    THROTTLE_KEY = "THROTTLE_KEY"
    EXTEND_TO_SCHEDULE = "EXTEND_TO_SCHEDULE"
    SMS_BODY = "SMS_BODY"
    CHAT_BODY = "CHAT_BODY"
    PUSH_BODY = "PUSH_BODY"
    PUSH_SUBJECT = "PUSH_SUBJECT"
    QUERY_EDITOR = "QUERY_EDITOR"
    DATA = "DATA"
    LAYOUT_EMAIL = "LAYOUT_EMAIL"
