"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class TimeRangeDtoTypedDict(TypedDict):
    start: str
    r"""Start time"""
    end: str
    r"""End time"""


class TimeRangeDto(BaseModel):
    start: str
    r"""Start time"""

    end: str
    r"""End time"""
