"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .getcontextresponsedto import GetContextResponseDto, GetContextResponseDtoTypedDict
from novu_py.types import BaseModel
from novu_py.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ContextsControllerGetContextRequestTypedDict(TypedDict):
    id: str
    r"""Context ID"""
    type: str
    r"""Context type"""
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class ContextsControllerGetContextRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Context ID"""

    type: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Context type"""

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class ContextsControllerGetContextResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetContextResponseDtoTypedDict


class ContextsControllerGetContextResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetContextResponseDto
