"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class EditorType(str, Enum):
    r"""Editor type of the layout."""

    HTML = "html"
    BLOCK = "block"


class EmailControlsDtoTypedDict(TypedDict):
    body: str
    r"""Body of the layout."""
    editor_type: EditorType
    r"""Editor type of the layout."""


class EmailControlsDto(BaseModel):
    body: str
    r"""Body of the layout."""

    editor_type: Annotated[EditorType, pydantic.Field(alias="editorType")]
    r"""Editor type of the layout."""
