"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class MetaDtoTypedDict(TypedDict):
    total_count: float
    r"""The total count of subscriber IDs provided"""
    successful: float
    r"""The count of successfully created subscriptions"""
    failed: float
    r"""The count of failed subscription attempts"""


class MetaDto(BaseModel):
    total_count: Annotated[float, pydantic.Field(alias="totalCount")]
    r"""The total count of subscriber IDs provided"""

    successful: float
    r"""The count of successfully created subscriptions"""

    failed: float
    r"""The count of failed subscription attempts"""
