"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CreateContextRequestDtoTypedDict(TypedDict):
    type: str
    r"""Context type (e.g., tenant, app, workspace). Must be lowercase alphanumeric with optional separators."""
    id: str
    r"""Unique identifier for this context. Must be lowercase alphanumeric with optional separators."""
    data: NotRequired[Dict[str, Any]]
    r"""Optional custom data to associate with this context."""


class CreateContextRequestDto(BaseModel):
    type: str
    r"""Context type (e.g., tenant, app, workspace). Must be lowercase alphanumeric with optional separators."""

    id: str
    r"""Unique identifier for this context. Must be lowercase alphanumeric with optional separators."""

    data: Optional[Dict[str, Any]] = None
    r"""Optional custom data to associate with this context."""
