"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DeleteTopicResponseDtoTypedDict(TypedDict):
    acknowledged: bool
    r"""Indicates if the operation was acknowledged"""


class DeleteTopicResponseDto(BaseModel):
    acknowledged: bool
    r"""Indicates if the operation was acknowledged"""
