"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CustomControlDtoTypedDict(TypedDict):
    custom: NotRequired[Dict[str, Any]]
    r"""Custom control values for the step."""


class CustomControlDto(BaseModel):
    custom: Optional[Dict[str, Any]] = None
    r"""Custom control values for the step."""
