"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .workflowlistresponsedto import (
    WorkflowListResponseDto,
    WorkflowListResponseDtoTypedDict,
)
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ListWorkflowResponseTypedDict(TypedDict):
    workflows: List[WorkflowListResponseDtoTypedDict]
    r"""List of workflows"""
    total_count: float
    r"""Total number of workflows"""


class ListWorkflowResponse(BaseModel):
    workflows: List[WorkflowListResponseDto]
    r"""List of workflows"""

    total_count: Annotated[float, pydantic.Field(alias="totalCount")]
    r"""Total number of workflows"""
