"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class StepTypeEnum(str, Enum):
    r"""Type of the step"""

    IN_APP = "in_app"
    EMAIL = "email"
    SMS = "sms"
    CHAT = "chat"
    PUSH = "push"
    DIGEST = "digest"
    TRIGGER = "trigger"
    DELAY = "delay"
    THROTTLE = "throttle"
    CUSTOM = "custom"
