"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ExecutionDetailsStatusEnum(str, Enum):
    r"""Status of the execution detail"""

    SUCCESS = "Success"
    WARNING = "Warning"
    FAILED = "Failed"
    PENDING = "Pending"
    QUEUED = "Queued"
    READ_CONFIRMATION = "ReadConfirmation"
