"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .stepcontentissuedto import StepContentIssueDto, StepContentIssueDtoTypedDict
from .stepintegrationissue import StepIntegrationIssue, StepIntegrationIssueTypedDict
from novu_py.types import BaseModel
from typing import Dict, List, Optional
from typing_extensions import NotRequired, TypedDict


class StepIssuesDtoTypedDict(TypedDict):
    controls: NotRequired[Dict[str, List[StepContentIssueDtoTypedDict]]]
    r"""Controls-related issues"""
    integration: NotRequired[Dict[str, List[StepIntegrationIssueTypedDict]]]
    r"""Integration-related issues"""


class StepIssuesDto(BaseModel):
    controls: Optional[Dict[str, List[StepContentIssueDto]]] = None
    r"""Controls-related issues"""

    integration: Optional[Dict[str, List[StepIntegrationIssue]]] = None
    r"""Integration-related issues"""
