"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriberdto import SubscriberDto, SubscriberDtoTypedDict
from .topicresponsedto import TopicResponseDto, TopicResponseDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class TopicSubscriptionResponseDtoTypedDict(TypedDict):
    id: str
    r"""The identifier of the subscription"""
    identifier: str
    r"""The identifier of the subscription"""
    created_at: str
    r"""The date and time the subscription was created"""
    topic: TopicResponseDtoTypedDict
    r"""Topic information"""
    subscriber: SubscriberDtoTypedDict
    r"""Subscriber information"""


class TopicSubscriptionResponseDto(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""The identifier of the subscription"""

    identifier: str
    r"""The identifier of the subscription"""

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]
    r"""The date and time the subscription was created"""

    topic: TopicResponseDto
    r"""Topic information"""

    subscriber: SubscriberDto
    r"""Subscriber information"""
